@@ -1,3 +1,5 @@
+import importlib.resources
+
 from typing import List, Optional
 
 
@@ -21,10 +23,9 @@ class Standings:
             if cache:
                 # load json from data/seasonal_information_manifest.json
                 import json
-                import os
 
-                with open(os.path.join(os.getcwd(), "nhlpy/data/seasonal_information_manifest.json"), "r") as f:
-                    seasons = json.load(f)["seasons"]
+                data_resource = importlib.resources.files("nhlpy") / "data"
+                seasons = json.loads((data_resource / "seasonal_information_manifest.json").read_text())["seasons"]
             else:
                 seasons = self.season_standing_manifest()
 
