@@ -1,4 +1,4 @@
-from nhlpy.api import teams, standings, schedule, game_center
+from nhlpy.api import teams, standings, schedule, game_center, stats, misc
 from nhlpy.http_client import HttpClient
 from nhlpy.config import ClientConfig
 
@@ -24,3 +24,5 @@ class NHLClient:
         self.standings = standings.Standings(http_client=self._http_client)
         self.schedule = schedule.Schedule(http_client=self._http_client)
         self.game_center = game_center.GameCenter(http_client=self._http_client)
+        self.stats = stats.Stats(http_client=self._http_client)
+        self.misc = misc.Misc(http_client=self._http_client)
